package com.gic.store.service.outer;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.store.dto.StoreFieldSelectDTO;
import com.gic.store.entity.TabStoreFieldSelect;
import com.gic.store.service.StoreFieldSelectApiService;
import com.gic.store.service.StoreFieldSelectService;
import com.gic.store.utils.ErrorCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * @author guojx
 * @date 2019/7/1 2:52 PM
 */
@Service("storeFieldSelectApiService")
public class StoreFieldSelectApiServiceImpl implements StoreFieldSelectApiService{
    @Autowired
    private StoreFieldSelectService storeFieldSelectService;

    @Override
    public ServiceResponse<Integer> save(StoreFieldSelectDTO storeFieldSelectDTO) {
        if (StringUtils.isBlank(storeFieldSelectDTO.getStoreFieldSelectName())) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "属性值名称不能为空");
        }
        if (StringUtils.isBlank(storeFieldSelectDTO.getStoreFieldSelectCode())) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "属性值code不能为空");
        }
        if (storeFieldSelectDTO.getStoreFieldId() == null) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "自定义字段值不能为空");
        }
        if (storeFieldSelectDTO.getEnterpriseId() == null) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "企业ID不能为空");
        }
        storeFieldSelectDTO.setCreateTime(new Date());
        storeFieldSelectDTO.setUpdateTime(new Date());

        return ServiceResponse.success(storeFieldSelectService.save(storeFieldSelectDTO));
    }

    @Override
    public ServiceResponse<Integer> upOrDown(int storeFieldSelectId, boolean isUp) {
        TabStoreFieldSelect tabStoreFieldSelect = storeFieldSelectService.getStoreFieldSelectById(storeFieldSelectId);
        if (tabStoreFieldSelect == null) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "主键错误，查询不到数据");
        }
        TabStoreFieldSelect needUpdateSort;
        if (isUp) {
            needUpdateSort = storeFieldSelectService.getPrevSort(tabStoreFieldSelect.getStoreFieldId(), tabStoreFieldSelect.getSort());
            if (needUpdateSort == null) {
                return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "已经是第一条，不能上移");
            }
        } else {
            needUpdateSort = storeFieldSelectService.getNextSort(tabStoreFieldSelect.getStoreFieldId(), tabStoreFieldSelect.getSort());
            if (needUpdateSort == null) {
                return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "已经是最后一条，不能下移");
            }
        }
        storeFieldSelectService.updateSortById(needUpdateSort.getStoreFieldSelectId(), tabStoreFieldSelect.getSort());
        storeFieldSelectService.updateSortById(tabStoreFieldSelect.getStoreFieldSelectId(), needUpdateSort.getSort());
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<Integer> setStoreFieldSelectSort(int storeFieldSelectId, int storeFieldId, int setValue) {
        storeFieldSelectService.setStoreFieldSelectSort(storeFieldSelectId, storeFieldId, setValue);
        return ServiceResponse.success(1);
    }

    @Override
    public ServiceResponse<Integer> delete(int storeFieldSelectId) {
        return ServiceResponse.success(storeFieldSelectService.delete(storeFieldSelectId));
    }

    @Override
    public ServiceResponse<Integer> edit(StoreFieldSelectDTO storeFieldSelectDTO) {
        if (StringUtils.isBlank(storeFieldSelectDTO.getStoreFieldSelectName())) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "属性值名称不能为空");
        }
        if (StringUtils.isBlank(storeFieldSelectDTO.getStoreFieldSelectCode())) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "属性值code不能为空");
        }
        if (storeFieldSelectDTO.getStoreFieldId() == null) {
            return ServiceResponse.failure(ErrorCode.ERR_5.getCode(), "主键ID不能为空");
        }
        return ServiceResponse.success(storeFieldSelectService.edit(storeFieldSelectDTO.getStoreFieldSelectId(),
                storeFieldSelectDTO.getStoreFieldSelectName(), storeFieldSelectDTO.getStoreFieldSelectCode()));
    }

}
