package com.gic.store.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.store.constant.StoreFieldTextEnum;
import com.gic.store.constant.StoreFieldTypeEnum;
import com.gic.store.constant.StoreGroupConstant;
import com.gic.store.dto.StoreFieldDTO;
import com.gic.store.dto.StoreFieldSelectDTO;
import com.gic.store.service.StoreFieldApiService;
import com.gic.store.service.StoreFieldSelectApiService;
import com.gic.store.web.qo.storefield.StoreFieldQO;
import com.gic.store.web.qo.storefield.StoreFieldSelectQO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

/**
 * @author guojx
 * @date 2019/6/28 2:01 PM
 */
@RestController
@RequestMapping("/store-field")
public class StoreFieldController {

    private static final Logger logger = LoggerFactory.getLogger(StoreFieldController.class);

    @Autowired
    private StoreFieldApiService storeFieldApiService;
    @Autowired
    private StoreFieldSelectApiService storeFieldSelectApiService;

    @RequestMapping("/list-store-field-type")
    public RestResponse listStoreFieldType() {
        Map<Integer, String> result = new HashMap<>(16);
        for (StoreFieldTypeEnum typeEnum : StoreFieldTypeEnum.values()) {
            result.put(typeEnum.getCode(), typeEnum.getMessage());
        }
        return RestResponse.success(result);
    }

    /**
     * 文本类型
     * @return
     */
    @RequestMapping("/list-store-field-text-type")
    public RestResponse listStoreFieldTextType() {
        Map<Integer, String> result = new HashMap<>(16);
        for (StoreFieldTextEnum typeEnum : StoreFieldTextEnum.values()) {
            result.put(typeEnum.getCode(), typeEnum.getMessage());
        }
        return RestResponse.success(result);
    }

    @RequestMapping("/save")
    public RestResponse save(@Validated({StoreFieldQO.SaveValidView.class}) StoreFieldQO storeFieldQO) {
        String regions = storeFieldQO.getStoreRegionIds();
        String[] regionArr = regions.split(",");
        StringBuilder region = new StringBuilder("_");
        for (String str : regionArr) {
            region.append(str);
            region.append("_");
        }
        storeFieldQO.setStoreRegionId(region.toString());
        ServiceResponse result = storeFieldApiService.save(transferQoToDTO(storeFieldQO));
        if (!result.isSuccess()) {
            return RestResponse.failure(result.getCode(), result.getMessage());
        }
        return RestResponse.success(result.getResult());
    }

    @RequestMapping("/save-select")
    public RestResponse saveFieldValue(@Validated({StoreFieldSelectQO.SaveValidView.class}) StoreFieldSelectQO storeFieldSelectQO) {
        ServiceResponse result = storeFieldSelectApiService.save(transferSelectQoToDTO(storeFieldSelectQO));
        if (result.isSuccess()) {
            return RestResponse.failure(result.getCode(), result.getMessage());
        } else {
            return RestResponse.success(result.getResult());
        }
    }

    private StoreFieldDTO transferQoToDTO(StoreFieldQO storeFieldQO) {
        StoreFieldDTO storeFieldDTO = EntityUtil.changeEntityNew(StoreFieldDTO.class, storeFieldQO);
        storeFieldDTO.setEnterpriseId(StoreGroupConstant.TEST_ENTERPRISE_ID);
        return storeFieldDTO;
    }

    private StoreFieldSelectDTO transferSelectQoToDTO(StoreFieldSelectQO storeFieldSelectQO) {
        StoreFieldSelectDTO storeFieldDTO = EntityUtil.changeEntityNew(StoreFieldSelectDTO.class, storeFieldSelectQO);
        storeFieldDTO.setEnterpriseId(StoreGroupConstant.TEST_ENTERPRISE_ID);
        return storeFieldDTO;
    }
}
